/* ReSCAL - Simulation of the very specific processes of the models
 *
 * Copyright (C) 2021
 *
 * Author: Olivier Rozier <rozier@ipgp.fr>
 *
 * This file is part of ReSCAL.
 *
 * ReSCAL is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/// List of specific events of the models

/// Event types
/// EVT_LGCA: perform one full cycle of lattice gas
/// EVT_NORMALS: compute normal vectors
/// EVT_CENTERING: automatic centering of the topography (north-south and east-west translation)
/// EVT_SUR: surrection of the topography (RIV model only)
/// EVT_ROT: rotation of the cellular space
/// EVT_AVA_SYNC: synchronized avalanches
/// EVT_AVA_DYN: temporal evolution of the rates and angles of avalanches
/// EVT_WIND: use wind data from external file (DUN model only)
/// EVT_SIGMA: compute and save standard deviation of a number of 2D topographies (-> stability analysis)
/// EVT_AUTO_COR: compute and save autocorrelation data on 2D topographies (-> stability analysis)
/// EVT_SAVE_FLUX: save FLUX data (DUN model only)
/// EVT_TOTAL_NUMBER: total number of event types (not an event type) - this value should be at the end of the list
enum EVT_TYPE_MOD {EVT_LGCA = EVT_GEN_NUMBER, EVT_NORMALS, EVT_CENTERING, EVT_SUR, EVT_ROT, EVT_AVA_SYNC, EVT_AVA_DYN, EVT_WIND,
     EVT_SIGMA, EVT_AUTOCOR, EVT_SAVE_FLUX, EVT_TOTAL_NUMBER};

/// Event names
#define EVT_NAME_MOD { "EVT_LGCA" , "EVT_NORMALS", "EVT_CENTERING", "EVT_SUR", "EVT_ROT", "EVT_AVA_SYNC", "EVT_AVA_DYN", "EVT_WIND", \
     "EVT_SIGMA", "EVT_AUTOCOR", "EVT_SAVE_FLUX" }


void params_simul_models();
void parse_simul_models();
void init_rot_mode();
void init_simul_models();
void simul_lgca();
void simul_lgca_coupling();
void simul_model(int ii);
double simul_model_event(int type);


